# Examples

Examples of how to use earthkit-climate

```{toctree}
:caption: 'Notebooks'
:maxdepth: 1

notebooks/aggregate-temporal.ipynb
notebooks/aggregate-climatology.ipynb
notebooks/aggregate-spatial.ipynb
```
